==> gbsite-1.0.0.tar.gz: gbsite/templates/ss/ss_homepage.php <==
<!--- ***
FILENAME:		ss_homepage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	homepage content
*** --->
<table cellspacing="0" cellpadding="0" border="0" width="100%">
<tr>
<td>
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">
<p><b><font color="<?= $color_6 ?>">Open Source Networking</font></b></p>

<p>Our mission is to startlingly redefine networking and networking services through open source
software development. </p>

<p>Our technology vision embraces open, Linux-based networking devices and services that enable
technological innovation to flourish and empower network engineers to customize networks from
the ground up. We are working to replace the legacy edges of the network with intelligent infrastructure
based on cost-effective off-the-shelf hardware running Open Source-developed software
modules. A number of excellent projects are already working to realize the vision; <b>we are
taking a revolutionary step forward</b>. At the core, we seek answers to the following questions:</p>

<p><center><i>What if you could program the network?</i></center></p>


<p><center><i>What if you could make the bits smarter?</i></center></p>

<p>To begin to address these questions, we have established this site as a community resource for
network engineers, developers and users. Over time, we hope this site will become THE
authoritative source for open source networking technologies on the Net.</p>

<p>Over the next several months, we will launch a number of open source networking projects on this
site, licensed under the GNU General Public License (<a href="http://www.gnu.org/">http://www.gnu.org</a>). We will also provide a number of free support
services to community members to host their own open source networking projects here. We <a href="/about/contact.php">invite you</a> to join our community of developers, users, and partners.</p>

<p><b>Check back with us as we roll out our new community website.</b></p>
</font>
</td>
</tr>
</table>

==> gbsite-1.1.1.tar.gz: gbsite/templates/ss/ss_homepage.php <==
<!--- ***
FILENAME:		ss_homepage.php
AUTHOR:			james bull - james@greatbridge.com
DESCRIPTION:	homepage content
*** --->
<table cellspacing="4" cellpadding="0" border="0" width="100%">
<tr>
<td valign="top" width="100%">
<font face="<?= $font_1 ?>" size="2" color="<?= $color_1?>">
<p>Our mission is to startlingly redefine networking and networking services through open source
software development. </p>

<p>Our technology vision embraces open, Linux-based networking devices and services that enable
technological innovation to flourish and empower network engineers to customize networks from
the ground up. We are working to replace the legacy edges of the network with intelligent infrastructure
based on cost-effective off-the-shelf hardware running Open Source-developed software
modules. A number of excellent projects are already working to realize the vision; <b>we are
taking a revolutionary step forward</b>. At the core, we seek answers to the following questions:</p>

<p><center><i>What if you could program the network?</i></center></p>


<p><center><i>What if you could make the bits smarter?</i></center></p>

<p>To begin to address these questions, we have established this site as a community resource for
network engineers, developers and users. Over time, we hope this site will become THE
authoritative source for open source networking technologies on the Net.</p>

<p>Over the next several months, we will launch a number of open source networking projects on this
site, licensed under the GNU General Public License (<a href="http://www.gnu.org/">http://www.gnu.org</a>). We will also provide a number of free support
services to community members to host their own open source networking projects here. We <a href="/about/contact.php">invite you</a> to join our community of developers, users, and partners.</p>

<p><b>Check back with us as we roll out our new community website.</b></p>
</font>
</td>
<td valign="top">
	<table cellspacing="0" cellpadding="2" border="0" width="100%">
	<tr>
	<td bgcolor="<?= $color_6 ?>"><font face="<?= $font_1 ?>" size="2" color="<?= $color_2 ?>"><b>Hosted Projects</b></font></td>
	</tr>
	<?
		while(list(,$value) = @each($proj_list)) {
		echo "
			<tr bgcolor=" . $color_7 . ">
			<td><font face=" . $font_1 . " size=2><a href=/project/" . $value["project_name"] . "/projdisplay.php><b>" . $value["project_name"] . "</b></a>&nbsp;" . $proj_status . "</font></td>
			</tr>
			<tr>
			<td>&nbsp;&nbsp;<font face=" . $font_1 . " size=2>" . $value["project_title"] . "</font></td>
			</tr>
			";
		}
	?>
	</table>
<!-- force cell width to 200 px -->
<br>
<img src="<?= $image_path ?>/shim.gif" width="200" height="1">
</td>
</tr>
</table>
